Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrEpisodeNotFound = errors.New("episode not found") ErrShowNotFound = errors.New("show not found") ErrInvalidArgument = errors.New("invalid argument") ErrMissingArgument = errors.New("missing argument") )
Eztv errors
Functions ¶
This section is empty.
Types ¶
type EpisodeTorrent ¶
type EpisodeTorrent struct {
ID int `json:"id"`
Hash string `json:"hash"`
Filename string `json:"filename"`
EpisodeURL string `json:"episode_url"`
TorrentURL string `json:"torrent_url"`
MagnetURL string `json:"magnet_url"`
Title string `json:"title"`
ImdbID string `json:"imdb_id"`
Season int `json:"season,string"`
Episode int `json:"episode,string"`
SmallScreenshot string `json:"small_screenshot"`
LargeScreenshot string `json:"large_screenshot"`
Seeds int `json:"seeds"`
Peers int `json:"peers"`
DateReleased time.Time `json:"date_released_unix"`
Size uint `json:"size_bytes,string"`
}
EpisodeTorrent represents a torrent for an episode
func GetEpisodeTorrents ¶
func GetEpisodeTorrents(ImdbID string, season, episode int) ([]*EpisodeTorrent, error)
GetEpisodeTorrents will get the torrents of show's episode from an ImdbID, a season number and an episode number
func GetShowTorrents ¶
func GetShowTorrents(imdbID string) ([]*EpisodeTorrent, error)
GetShowTorrents will get the torrents of a show from an ImdbID
func GetTorrents ¶
func GetTorrents(limit, page int) ([]*EpisodeTorrent, error)
GetTorrents will get torrents, given a limit and a page number
func (*EpisodeTorrent) UnmarshalJSON ¶
func (t *EpisodeTorrent) UnmarshalJSON(data []byte) error
UnmarshalJSON implements the Unmarshaller interface
Click to show internal directories.
Click to hide internal directories.